/**
 * Component to render data for not conserved assets sheet
 * @class NotConservedSheet
 */
export class NotConservedSheet {
    /**
     * @param {object} data
     */
    set siteData(data) {
        this._data = data;
    }

    async render() {
        return `
        <div class="container ml-3">
            <p class="p-2">
                <span class="icon has-text-link">
                    <i class="fa fa-tag"></i>
                </span>
                <strong>Denominazione:</strong> ${this._data.denomination}
            </p>
            <p class="p-2">
                <span class="icon has-text-link">
                    <i class="fa fa-hourglass"></i>
                </span>
                <strong>Periodo:</strong> ${this._data.period}
            </p>
            <p class="p-2">
                <span class="icon has-text-link">
                    <i class="fa fa-map"></i>
                </span>
                <strong>Località generica:</strong> ${this._data.genericLocation}
            </p>
            <p class="mt-4 pl-2 pr-5">
                <strong class="pb-3">Descrizione</strong></br>
                ${this._data.shortDescription}
            </p>
            <p class="mt-4 pl-2 pr-5">
                <span class="icon has-text-link">
                    <i class="fa fa-book"></i>
                </span>
                <strong>Bibliografia:</strong> ${await this.biblio(this._data.id)}
            </p>
            <p class="p-2">
                <span class="icon has-text-link">
                    <i class="fa fa-map"></i>
                </span>
                <strong>Autore scheda:</strong> ${this._data.author}
            </p>
        </div>`;
    }

    async biblio(recordId) {
        let record = await this.fetchData(`${window.API_URL}/not_conserved/${recordId}`);

        let biblio = '';

        if (record.bibliography.length) {
            record.bibliography.forEach(record => {
                biblio += `
                    <span class="is-capitalized">${record.citation.toLowerCase()}</span>,
                    ${record.pages};
                `;
            });
        }

        return biblio.trim().slice(0, -1);
    }

    async fetchData(url) {
        return await fetch(url).then(res => res.json());
    }
}
